FlutterNativeAdImage class

Represents a single image in a Native Ad with its associated metadata.

Constructors

FlutterNativeAdImage({String? url, double? width, double? height, double? scale})
FlutterNativeAdImage.fromMap(Map<String, dynamic> map)
Creates a FlutterNativeAdImage from a map.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
height → double?
The height of the image in pixels (if available).
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scale → double?
The scale of the image (if available).
final
url → String?
The URL string for the image.
final
width → double?
The width of the image in pixels (if available).
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
Backward-compatible way to get the URL if you treat this as a string.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited