NativeAdGenericMediationExtras class

A generic implementation of NativeAdMediationExtras to support any mediation provider.

Inheritance

Constructors

NativeAdGenericMediationExtras({required String androidClassName, required String iosClassName, required Map<String, dynamic> extras})

Properties

androidClassName → String
final
extras → Map<String, dynamic>
final
hashCode → int
The hash code for this object.
no setterinherited
iosClassName → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAndroidClassName() → String
Fully-qualified name of an Android MediationExtras class.
override
getExtras() → Map<String, dynamic>
Key-Value pair to be sent to the host platform to parse.
override
getIOSClassName() → String
Name of an iOS class that conforms to the GADAdNetworkExtras protocol.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the extras into a Map for transmission over the method channel.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited