NativeAdMediationExtras class abstract

Contains information for a particular ad network set by the developer.

Implementers

Constructors

NativeAdMediationExtras()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

getAndroidClassName() → String
Fully-qualified name of an Android MediationExtras class.
getExtras() → Map<String, dynamic>
Key-Value pair to be sent to the host platform to parse.
getIOSClassName() → String
Name of an iOS class that conforms to the GADAdNetworkExtras protocol.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
Converts the extras into a Map for transmission over the method channel.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited