MethodChannelFlutterNativeAdmobAds class
An implementation of FlutterNativeAdmobAdsPlatform that uses method channels.
- Inheritance
-
- Object
- PlatformInterface
- FlutterNativeAdmobAdsPlatform
- MethodChannelFlutterNativeAdmobAds
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- methodChannel → MethodChannel
-
The method channel used to interact with the native platform.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disposeNativeAd(
String id) → Future< void> -
Disposes of the specified ad.
override
-
loadNativeAd(
{required String adId, bool isTesting = false, int adsCount = 1}) → Future< List< FlutterNativeAd> > -
Loads one or more native ads with the specified options.
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
triggerNativeAd(
String id) → Future< void> -
Triggers a click on the specified ad.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited