native_ad_models
library
Classes
-
FlutterNativeAd
-
Represents a loaded Native Ad from AdMob with all available metadata.
-
FlutterNativeAdImage
-
Represents a single image in a Native Ad with its associated metadata.
-
FlutterNativeAdOptions
-
Options for loading one or more native ads.
-
A generic implementation of NativeAdMediationExtras to support any mediation provider.
-
Contains information for a particular ad network set by the developer.
-
NativeAdRequest
-
Represents an NativeAdRequest with various targeting and configuration options.