FlutterNativeAdOptions class
Options for loading one or more native ads.
Constructors
- FlutterNativeAdOptions({required String adId, bool isTesting = false, int adsCount = 1})
- Creates a new FlutterNativeAdOptions instance.
Properties
- adId → String
-
The AdMob ad unit ID to load.
final
- adsCount → int
-
The number of ads to request from the server (min 1, max 5).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isTesting → bool
-
Whether to use test ads instead of live ads.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts the options into a Map for transmission over the method channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited