NativeAdRequest class
Represents an NativeAdRequest with various targeting and configuration options.
Constructors
Properties
- contentUrl → String?
-
The content URL for the ad request.
final
-
extras
→ Map<
String, String> ? -
A map of extra parameters.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- httpTimeoutMillis → int?
-
The HTTP timeout in milliseconds.
final
-
keywords
→ List<
String> ? -
A list of keywords to be used for targeting.
final
-
mediationExtras
→ List<
NativeAdMediationExtras> ? -
A list of mediation extras.
final
- mediationExtrasIdentifier → String?
-
An identifier for mediation extras.
final
-
neighboringContentUrls
→ List<
String> ? -
A list of neighboring content URLs for the ad request.
final
- nonPersonalizedAds → bool?
-
Whether non-personalized ads should be requested.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toMap(
) → Map< String, dynamic> - Converts the NativeAdRequest into a Map for transmission over the method channel.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited